@@ -4,6 +4,17 @@ import urllib.request, json
 from collections.abc import Iterable
 from datetime import datetime, timedelta
 
+__pdoc__ = {
+    'isStr': False,
+    'isStrIterable': False,
+    'isDatetime': False,
+    'isDatetimeIterable': False,
+    'isNumeric': False,
+    'isNumericIterable': False,
+    'parse': False,
+}
+
+
 def isStr(obj):
     return isinstance(obj,str)
 
@@ -47,27 +58,26 @@ def getData(variables,dates=None,start=None,end=None,quality='ANY',averaging='1'
     Parameters
     ----------
 
-    variables: string or array of strings
-        name of a measured quantity in the database
-        (tablevariable)
+    variables : string or array of strings
+        name of a measured quantity in the database (tablevariable)
 
-    dates: datetime object or string or array of datetime objects or strings
+    dates : datetime object or string or array of datetime objects or strings
         the date(s) for which measurements are downloaded
 
-    start: datetime object or string
+    start : datetime object or string
         begin of measurement
 
-    end: datetime object or string
+    end : datetime object or string
         end of measurement
     
-    quality: string
-        "ANY"
+    quality : string
+        `"ANY"`
     
-    averaging: string
-        "1" (no averaging) or "30" (30 min) or "60" (60 min)
+    averaging : string
+        `"1"` (no averaging), `"30"` (30 min) or `"60"` (60 min)
     
-    avg_type: string
-        "NONE" or "ARITHMETIC" or "MEDIAN" or "MIN" or "MAX"
+    avg_type : string
+        `"NONE"`, `"ARITHMETIC"`, `"MEDIAN"`, `"MIN"` or `"MAX"`
 
     Returns
     -------
@@ -75,11 +85,6 @@ def getData(variables,dates=None,start=None,end=None,quality='ANY',averaging='1'
     pandas DataFrame or list of DataFrames
         downloaded data, list is given for array of date objects
 
-        In the dataframes:
-        index   : time
-        columns : variables
-        values  : data
-
     """
 
     if isStrIterable(variables):
@@ -194,36 +199,17 @@ def listAllData(search_term=None,verbose=False):
     Parameters
     ----------
     
-    search_term: string
-        search term for searching the database
+    search_term : string
+        search term for searching the database, if `None`
+        all results are returned.
 
-    verbose: boolean
+    verbose : boolean
         verbose or not verbose output
 
     Returns
     -------
 
-    df: pandas DataFrame
-
-        rows: represent different variables
-
-        if verbose is True:
-        
-            columns:
-                title: name of the variable
-                tablevariable: name used when downloading data
-                description: description of the measurement
-                source: instrument producing the data
-
-        if verbose is False:
-
-            columns:
-                title: name of the variable
-                tablevariable: name used when downloading data
-
-    If search_term is given return only variables that
-    contain the search_term in their title, otherwise
-    return all variables in the database.
+    pandas DataFrame
 
     """
 
@@ -317,13 +303,13 @@ def getVariableMetadata(variables):
     Parameters
     ----------
 
-    variables: string or array of strings
+    variables : string or array of strings
         name (tablevariable) of a measured quantity in the database
 
     Returns
     -------
 
-    dict or list of dicts
+    dictionary or list of dictionaries
         metadata for given tablevariables
         
     """
@@ -354,36 +340,36 @@ def getDmpsData(station='HYY',start=None,end=None,dates=None,quality='ANY',avera
     Parameters
     ----------
 
-    station: string
-        "HYY", "KUM" or "VAR"
+    station : string
+        `"HYY"`, `"KUM"` or `"VAR"`
 
-    dates: datetime object or string or array of datetime objects or strings
+    dates : datetime object or string or array of datetime objects or strings
         the days for which data is are downloaded
 
-    start: datetime object or string
+    start : datetime object or string
         begin time for data
 
-    end: datetime object or string
+    end : datetime object or string
         end time for data
     
-    quality: string
-        "ANY"
+    quality : string
+        `"ANY"`
     
-    averaging: string
-        "1" (no averaging) or "30" (30 minutes) or "60" (60 minutes)
+    averaging : string
+        `"1"` (no averaging), `"30"` (30 minutes) or `"60"` (60 minutes)
     
-    avg_type: str
-        "NONE" or "ARITHMETIC" or "MEDIAN" or "MIN" or "MAX"
+    avg_type : str
+        `"NONE"`, `"ARITHMETIC"`, `"MEDIAN"`, `"MIN"` or `"MAX"`
 
     Returns
     -------
     
     pandas DataFrame or list of DataFrames
-        downloaded data, list is given when dates is array    
-     
-        index   : time (utc+2)
-        columns : bin geometric mean diameters (m)
-        values  : dN/dlogDp (cm-3)
+        downloaded data, list is given when dates is array 
+        
+        index = time (utc+2)  
+        columns = bin geometric mean diameters (m)  
+        values = dN/dlogDp (cm-3)
 
     """
 
@@ -545,219 +531,3 @@ def getDmpsData(station='HYY',start=None,end=None,dates=None,quality='ANY',avera
 
     else:
         raise Exception('Missing "start" and "end" or "dates"')
-
-
-
-def calc_concentration(dp,data,dmin,dmax):
-    """ Calculate number concentration """
-    findex=np.argwhere((dp<=dmax)&(dp>=dmin)).flatten()
-    if len(findex)==0:
-        return np.nan*np.ones(data.shape[0])
-    dp=dp[findex]
-    conc=data[:,findex]
-    logdp_mid=np.log10(dp)
-    logdp=(logdp_mid[:-1]+logdp_mid[1:])/2.0
-    logdp=np.append(logdp,logdp_mid.max()+(logdp_mid.max()-logdp.max()))
-    logdp=np.insert(logdp,0,logdp_mid.min()-(logdp.min()-logdp_mid.min()))
-    dlogdp=np.diff(logdp)
-    return np.sum(conc*dlogdp,axis=1)
-
-
-def getConcData(station='HYY',dp1=None,dp2=None,start=None,end=None,dates=None,quality='ANY',averaging='1',avg_type='NONE'):
-    """ Get number concentration in a size range 
-    
-    Parameters
-    ----------
-
-    station: string
-        "HYY", "KUM" or "VAR"
-
-    dp1: float
-        Lower diameter limit in nanometers
-
-    dp2: float
-        Upper diameter limit in nanometers
-
-    dates: datetime object/string or array of datetime objects/strings
-        the days for which data is are downloaded
-
-    start: datetime object/string
-        begin time for data
-
-    end: datetime object/string
-        end time for data
-    
-    quality: string
-        "ANY"
-    
-    averaging: string
-        "1" (no averaging) or "30" (30 minutes) or "60" (60 minutes)
-    
-    avg_type: str
-        "NONE" or "ARITHMETIC" or "MEDIAN" or "MIN" or "MAX"
-
-    Returns
-    -------
-    
-    pandas DataFrame or list of DataFrames
-        Calculated number concentrations, 
-        list is given when dates is array    
-     
-        index   : time (utc+2)
-        values  : number concs [cm-3]
-    """
-   
-    # Use the getDmpsData to retrieve size distribution data
-    dmpsData = getDmpsData(station=station,start=start,end=end,dates=dates,quality=quality,averaging=averaging,avg_type=avg_type)
- 
-    if len(dmpsData)==0:
-        return dmpsData
-
-    if (dp1 is not None) and (dp2 is not None):
-
-        if (isNumeric(dp1) and isNumeric(dp2)):
-
-            # dp2 must be greater than dp1
-            if dp2<=dp1:
-                raise Exception("dp2>dp1")
-
-            if isinstance(dmpsData,list):
-
-                result=[]
-                for x in dmpsData:
-                    if x.empty:
-                        result.append(pd.DataFrame([]))
-                    else:
-                        time = x.index.values
-                        diams = x.columns.values
-                        dndlogdp = x.values
-                        conc = calc_concentration(diams,dndlogdp,dp1,dp2)
-                        df = pd.DataFrame(index=time, columns=['conc'], data=conc)
-                        result.append(df)
-                return result
-
-            else:
-                time = dmpsData.index.values
-                diams = dmpsData.columns.values
-                dndlogdp = dmpsData.values
-                conc = calc_concentration(diams,dndlogdp,dp1,dp2)
-                result = pd.DataFrame(index=time, columns=['conc'], data=conc)
-                return result
-
-        else:
-            raise Exception('"dp1" and "dp2" must be numeric')
-
-    else:
-        raise Exception('Missing "dp1" and "dp2"')
-
-
-
-def calc_cs(time,dp,temp,pres,dNdlogDp):
-    """ Calculate condensation sink """
-
-    Mx=98.08
-    Mair=28.965
-    Dair=19.7
-    Dx=51.96
-    k=8314.7
-
-    R = dp/2.0
-    Pr = pres/101325.
-    Temp = temp
-
-    CS = np.nan * np.ones(len(time))
-
-    for i in range(len(CS)):
-        Dif = (0.001 * (Temp[i]**1.75)*np.sqrt( (1./Mair)+(1./Mx))) / (Pr[i]*(Dair**(1./3.)+Dx**(1./3.))**2.)
-        lam=3.*(np.sqrt( (np.pi*Mx)/(8.*k*Temp[i]) )) * Dif *1e-4
-        knud=lam/R
-        beta=(knud+1.)/((0.377*knud)+1.+(4./(3.*1.))*(knud**2.)+(4./(3.*1))*knud)
-        CS[i] = np.nansum((4.*np.pi*Dif)*dNdlogDp[i,:]*beta*R*1e2)
-
-    df = pd.DataFrame(index=time, columns=['cs'], data=CS)
-    
-    return df
-
-def getCS(station='HYY',start=None,end=None,dates=None,quality='ANY',averaging='1',avg_type='NONE'):
-    """ Calculate CS from aerosol size distribution
- 
-    Parameters
-    ----------
- 
-    station: string
-        "HYY", "KUM" or "VAR"
- 
-    dates: datetime object/string or array of datetime objects/strings
-        the days for which data is/are downloaded
- 
-    start: datetime object/string
-        begin time for data
- 
-    end: datetime object/string
-        end time for data
-    
-    quality: string
-        "ANY"
-    
-    averaging: string
-        "1" (no averaging) or "30" (30 minutes) or "60" (60 minutes)
-    
-    avg_type: str
-        "NONE" or "ARITHMETIC" or "MEDIAN" or "MIN" or "MAX"
- 
-    Returns
-    -------
-    
-    pandas DataFrame or list of DataFrames
-        Calculated condensation sink, 
-        list is given when dates is array    
-     
-        index   : time (utc+2)
-        values  : condensation sink [s-1] 
- 
-    """
-
-    # Determine the temperature and pressure tablevariables
-    if (station=="KUM"):
-        temp_tv = 'KUM_META.t'
-        pres_tv = 'KUM_META.p'
-    elif (station=="HYY"):
-        temp_tv = 'HYY_META.T84'
-        pres_tv = 'HYY_META.Pamb0'
-    elif (station=="VAR"):
-        temp_tv = 'VAR_META.TDRY0'
-        pres_tv = 'VAR_META.P'
-    else:
-        pass
-
-    # Download the required data
-    dmpsData = getDmpsData(station=station,start=start,end=end,dates=dates,quality=quality,averaging=averaging,avg_type=avg_type)
-    tempData = getData(temp_tv,start=start,end=end,dates=dates,quality=quality,averaging=averaging,avg_type=avg_type)
-    presData = getData(pres_tv,start=start,end=end,dates=dates,quality=quality,averaging=averaging,avg_type=avg_type)
-
-    if isinstance(dmpsData,list):        
-        result = []
-        for i in range(len(dmpsData)):
-            if (dmpsData[i].empty | tempData[i].empty | presData[i].empty):
-                result.append(pd.DataFrame([]))
-            else:
-                dp = dmpsData[i].columns.values
-                dndlogdp = dmpsData[i].values
-                temp = tempData[i].reindex(dmpsData[i].index, method='nearest').values
-                pres = presData[i].reindex(dmpsData[i].index, method='nearest').values
-                time = dmpsData[i].index
-                df = calc_cs(time,dp,temp+273.15,pres*100.0,dndlogdp)
-                result.append(df)
-        return result
-
-    else:
-        if (dmpsData.empty | tempData.empty | presData.empty):
-            return pd.DataFrame([])
-        else:
-            dp = dmpsData.columns.values
-            dndlogdp = dmpsData.values
-            pres = presData.reindex(dmpsData.index, method='nearest').values
-            temp = tempData.reindex(dmpsData.index, method='nearest').values
-            time = dmpsData.index
-            df = calc_cs(time,dp,temp+273.15,pres*100.0,dndlogdp)
-            return df
